@@ -1,7 +1,13 @@
 package Mojo::Util::Collection;
 use Mojo::Base -base;
 
-our $VERSION = '0.0.8';
+use Exporter 'import';
+
+our @EXPORT_OK = qw(
+    collect
+);
+
+our $VERSION = '0.0.9';
 
 use List::Util;
 use Scalar::Util qw(blessed);
@@ -63,7 +69,7 @@ sub add {
     } elsif (blessed($object)) {
         if ($object->isa('Mojo::Util::Collection')) {
             push(@objects, @{ $object->objects });
-        } elsif ($object->isa(ref($self->model))) {
+        } elsif ($object->isa('Mojo::Util::Model')) {
             push(@objects, $object);
         } else {
             warn "Can't add object of type " . ref($object);
@@ -77,6 +83,20 @@ sub add {
     return $self;
 }
 
+=head2 as
+
+Set model for collection
+
+=cut
+
+sub as {
+    my ($self, $as) = @_;
+
+    $self->model($as);
+
+    return $self;
+}
+
 =head2 asOptions
 
 Return an array ref containing [{ value => $value, label => $label }, ...]
@@ -102,6 +122,18 @@ sub avg {
     return List::Util::sum(@$values) / scalar(@$values);
 }
 
+=head2 collect
+
+Instantiate a new collection
+
+=cut
+
+sub collect {
+    my $items = shift;
+
+    return Mojo::Util::Collection->new({ items => $items });
+}
+
 =head2 count
 
 Return the size of objects
@@ -159,7 +191,7 @@ sub filter {
 
     my @objects = grep { $callback->($_) } @{ $self->objects };
 
-    return $self->new({ objects => \@objects, model => $self->model });
+    return $self->new({ objects => \@objects })->as($self->model);
 }
 
 =head2 find
@@ -351,6 +383,10 @@ C<Model> object
 sub newObject {
     my $self = shift;
 
+    if (ref($self->model) eq 'CODE') {
+        return $self->model->(@_);
+    }
+
     return $self->model->new(@_);
 }
 
@@ -450,7 +486,7 @@ sub page {
     my $start = ($page - 1) * $self->limit;
     my $end = List::Util::min(($page * $self->limit), scalar(@objects)) - 1;
 
-    retun $self->slice($start, $end);
+    return $self->slice($start, $end);
 }
 
 =head2 remove
@@ -531,7 +567,7 @@ sub slice {
     my @objects = @{ $self->objects };
     my @partition = @objects[$start .. $end];
 
-    return $self->new({ objects => \@partition, model => $self->model });
+    return $self->new({ objects => \@partition })->as($self->model);
 }
 
 =head2 splice
