@@ -1,17 +1,19 @@
 package Mojo::Util::Collection::Comparator;
 use Mojo::Base -base;
 
-our $VERSION = '0.0.8';
+our $VERSION = '0.0.9';
 
 use List::Util qw(all any none);
 
 has 'specials' => sub {{
-    '==' => 'eq',
-    '>'  => 'gt',
-    '>=' => 'ge',
-    '<'  => 'lt',
-    '<=' => 'le',
-    '!=' => 'ne',
+    '=='            => 'eq',
+    '>'         => 'gt',
+    '>='        => 'ge',
+    '<'         => 'lt',
+    '<='        => 'le',
+    '!='        => 'ne',
+    'not_like'  => 'notLike',
+    'not_match' => 'notMatch'
 }};
 
 =head2 between
@@ -182,6 +184,34 @@ sub ne {
     return ($a != $b) ? 1 : 0;
 }
 
+=head2 notLike
+
+Alias for notMatch
+
+Returns:
+C<Int> 1/0
+
+=cut
+
+sub notLike {
+    return shift->notMatch(@_);
+}
+
+=head2 notMatch
+
+Check if search does not match pattern
+
+Returns:
+C<Int> 1/0
+
+=cut
+
+sub notMatch {
+    my ($self, $search, $pattern) = @_;
+
+    return $search !~ m/$pattern/ ? 1 : 0;
+}
+
 =head2 verify
 
 Check if a matches the conditions from b
